@@ -28,3 +28,35 @@ __PACKAGE__->set_primary_key("word", "type");
 __PACKAGE__->resultset_class('Foorum::ResultSet::FilterWord');
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::FilterWord - Table 'filter_word'
+
+=head1 COLUMNS
+
+=over 4
+
+=item word
+
+VARCHAR(64)
+
+NOT NULL, PRIMARY KEY
+
+=item type
+
+ENUM(19)
+
+NOT NULL, PRIMARY KEY, DEFAULT VALUE 'username_reserved'
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
