@@ -28,3 +28,41 @@ __PACKAGE__->add_columns(
 __PACKAGE__->set_primary_key("forum_id", "type");
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::ForumSettings - Table 'forum_settings'
+
+=head1 COLUMNS
+
+=over 4
+
+=item forum_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item type
+
+VARCHAR(48)
+
+NOT NULL, PRIMARY KEY
+
+=item value
+
+VARCHAR(48)
+
+NOT NULL
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
