@@ -30,3 +30,47 @@ __PACKAGE__->add_columns(
 __PACKAGE__->set_primary_key("error_id");
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::LogError - Table 'log_error'
+
+=head1 COLUMNS
+
+=over 4
+
+=item error_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item level
+
+ENUM(5)
+
+NOT NULL, DEFAULT VALUE 'debug'
+
+=item text
+
+TEXT(65535)
+
+NOT NULL
+
+=item time
+
+INT(11)
+
+NOT NULL
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
