@@ -16,3 +16,35 @@ __PACKAGE__->add_columns(
 __PACKAGE__->set_primary_key("message_id", "user_id");
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::MessageUnread - Table 'message_unread'
+
+=head1 COLUMNS
+
+=over 4
+
+=item message_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item user_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
