@@ -49,3 +49,83 @@ __PACKAGE__->has_many(
     { 'foreign.poll_id' => 'self.poll_id' }
 );
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::Poll - Table 'poll'
+
+=head1 COLUMNS
+
+=over 4
+
+=item poll_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item forum_id
+
+INT(11)
+
+NOT NULL
+
+=item author_id
+
+INT(11)
+
+NOT NULL
+
+=item multi
+
+ENUM(1)
+
+NOT NULL
+
+=item anonymous
+
+ENUM(1)
+
+NOT NULL
+
+=item time
+
+INT(10)
+
+
+
+=item duration
+
+INT(10)
+
+
+
+=item vote_no
+
+MEDIUMINT(8)
+
+NOT NULL
+
+=item title
+
+VARCHAR(128)
+
+
+
+=item hit
+
+INT(11)
+
+NOT NULL
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
