@@ -33,3 +33,47 @@ __PACKAGE__->has_many(
     { 'foreign.option_id' => 'self.option_id' }
 );
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::PollOption - Table 'poll_option'
+
+=head1 COLUMNS
+
+=over 4
+
+=item option_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item poll_id
+
+INT(11)
+
+NOT NULL
+
+=item text
+
+VARCHAR(255)
+
+
+
+=item vote_no
+
+MEDIUMINT(8)
+
+NOT NULL
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
