@@ -67,3 +67,77 @@ __PACKAGE__->set_primary_key("email_id");
 __PACKAGE__->resultset_class('Foorum::ResultSet::ScheduledEmail');
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::ScheduledEmail - Table 'scheduled_email'
+
+=head1 COLUMNS
+
+=over 4
+
+=item email_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item email_type
+
+VARCHAR(24)
+
+
+
+=item processed
+
+ENUM(1)
+
+NOT NULL, DEFAULT VALUE 'N'
+
+=item from_email
+
+VARCHAR(128)
+
+
+
+=item to_email
+
+VARCHAR(128)
+
+
+
+=item subject
+
+TEXT(65535)
+
+
+
+=item plain_body
+
+TEXT(65535)
+
+
+
+=item html_body
+
+TEXT(65535)
+
+
+
+=item time
+
+INT(11)
+
+NOT NULL
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
