@@ -25,3 +25,47 @@ __PACKAGE__->add_columns(
 __PACKAGE__->set_primary_key("stat_id");
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::Stat - Table 'stat'
+
+=head1 COLUMNS
+
+=over 4
+
+=item stat_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item stat_key
+
+VARCHAR(255)
+
+NOT NULL
+
+=item stat_value
+
+BIGINT(21)
+
+NOT NULL
+
+=item date
+
+DATE(10)
+
+NOT NULL
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
