@@ -12,6 +12,13 @@ __PACKAGE__->add_columns(
   { data_type => "INT", default_value => undef, is_nullable => 0, size => 11 },
   "forum_id",
   { data_type => "INT", default_value => 0, is_nullable => 0, size => 11 },
+  "post_on",
+  {
+    data_type => 'INT',
+    default_value => 0,
+    is_nullable => 0,
+    size => 11,
+  },
   "title",
   {
     data_type => "VARCHAR",
@@ -66,3 +73,101 @@ __PACKAGE__->belongs_to(
 __PACKAGE__->resultset_class('Foorum::ResultSet::Topic');
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::Topic - Table 'topic'
+
+=head1 COLUMNS
+
+=over 4
+
+=item topic_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item forum_id
+
+INT(11)
+
+NOT NULL
+
+=item post_on
+
+INT(11)
+
+NOT NULL
+
+=item title
+
+VARCHAR(255)
+
+
+
+=item closed
+
+ENUM(1)
+
+NOT NULL
+
+=item sticky
+
+ENUM(1)
+
+NOT NULL
+
+=item elite
+
+ENUM(1)
+
+NOT NULL
+
+=item hit
+
+INT(11)
+
+NOT NULL
+
+=item last_updator_id
+
+INT(11)
+
+NOT NULL
+
+=item last_update_date
+
+INT(11)
+
+
+
+=item author_id
+
+INT(11)
+
+NOT NULL
+
+=item total_replies
+
+INT(11)
+
+NOT NULL
+
+=item status
+
+ENUM(7)
+
+NOT NULL, DEFAULT VALUE 'healthy'
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
