@@ -31,3 +31,59 @@ __PACKAGE__->set_primary_key("upload_id");
 __PACKAGE__->resultset_class('Foorum::ResultSet::Upload');
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::Upload - Table 'upload'
+
+=head1 COLUMNS
+
+=over 4
+
+=item upload_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item user_id
+
+INT(11)
+
+NOT NULL
+
+=item forum_id
+
+INT(11)
+
+NOT NULL
+
+=item filename
+
+VARCHAR(36)
+
+
+
+=item filesize
+
+DOUBLE(64)
+
+
+
+=item filetype
+
+VARCHAR(4)
+
+
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
