@@ -22,3 +22,47 @@ __PACKAGE__->set_primary_key("user_id", "forum_id");
 __PACKAGE__->resultset_class('Foorum::ResultSet::UserForum');
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+Foorum::Schema::UserForum - Table 'user_forum'
+
+=head1 COLUMNS
+
+=over 4
+
+=item user_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item forum_id
+
+INT(11)
+
+NOT NULL, PRIMARY KEY
+
+=item status
+
+ENUM(9)
+
+NOT NULL, DEFAULT VALUE 'user'
+
+=item time
+
+INT(11)
+
+NOT NULL
+
+=back
+
+=head2 AUTHOR
+
+Fayland Lam <fayland at gmail.com>
+
+=cut
+
